==> jupytercad_core-2.0.0a4.tar.gz: jupytercad_core-2.0.0a4/lib/jcadplugin/plugins.js <==
import { ICollaborativeDrive } from '@jupyter/docprovider';
import { IAnnotationToken, IJCadExternalCommandRegistryToken, IJCadWorkerRegistryToken, IJupyterCadDocTracker, JupyterCadDoc } from '@jupytercad/schema';
import { ICommandPalette, IThemeManager } from '@jupyterlab/apputils';
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
import { ILauncher } from '@jupyterlab/launcher';
import { fileIcon } from '@jupyterlab/ui-components';
import { JupyterCadWidgetFactory } from '../factory';
import { JupyterCadJcadModelFactory } from './modelfactory';
const FACTORY = 'JupyterCAD .jcad Viewer';
const PALETTE_CATEGORY = 'JupyterCAD';
var CommandIDs;
(function (CommandIDs) {
    CommandIDs.createNew = 'jupytercad:create-new-jcad-file';
})(CommandIDs || (CommandIDs = {}));
const activate = (app, tracker, themeManager, annotationModel, browserFactory, workerRegistry, externalCommandRegistry, launcher, palette, drive) => {
    const widgetFactory = new JupyterCadWidgetFactory({
        name: FACTORY,
        modelName: 'jupytercad-jcadmodel',
        fileTypes: ['jcad'],
        defaultFor: ['jcad'],
        tracker,
        commands: app.commands,
        workerRegistry,
        externalCommandRegistry
    });
    // Registering the widget factory
    app.docRegistry.addWidgetFactory(widgetFactory);
    // Creating and registering the model factory for our custom DocumentModel
    const modelFactory = new JupyterCadJcadModelFactory({
        annotationModel
    });
    app.docRegistry.addModelFactory(modelFactory);
    // register the filetype
    app.docRegistry.addFileType({
        name: 'jcad',
        displayName: 'JCAD',
        mimeTypes: ['text/json'],
        extensions: ['.jcad', '.JCAD'],
        fileFormat: 'text',
        contentType: 'jcad'
    });
    const jcadSharedModelFactory = () => {
        return new JupyterCadDoc();
    };
    if (drive) {
        drive.sharedModelFactory.registerDocumentFactory('jcad', jcadSharedModelFactory);
    }
    widgetFactory.widgetCreated.connect((sender, widget) => {
        widget.context.pathChanged.connect(() => {
            tracker.save(widget);
        });
        themeManager.themeChanged.connect((_, changes) => widget.context.model.themeChanged.emit(changes));
        tracker.add(widget);
        app.shell.activateById('jupytercad::leftControlPanel');
        app.shell.activateById('jupytercad::rightControlPanel');
    });
    app.commands.addCommand(CommandIDs.createNew, {
        label: args => 'New JCAD File',
        caption: 'Create a new JCAD Editor',
        icon: args => (args['isPalette'] ? undefined : fileIcon),
        execute: async (args) => {
            var _a;
            // Get the directory in which the JCAD file must be created;
            // otherwise take the current filebrowser directory
            const cwd = (args['cwd'] ||
                ((_a = browserFactory.tracker.currentWidget) === null || _a === void 0 ? void 0 : _a.model.path));
            // Create a new untitled Blockly file
            let model = await app.serviceManager.contents.newUntitled({
                path: cwd,
                type: 'file',
                ext: '.jcad'
            });
            model = await app.serviceManager.contents.save(model.path, Object.assign(Object.assign({}, model), { format: 'text', size: undefined, content: '{\n\t"objects": [],\n\t"options": {},\n\t"metadata": {},\n\t"outputs": {}}' }));
            // Open the newly created file with the 'Editor'
            return app.commands.execute('docmanager:open', {
                path: model.path,
                factory: FACTORY
            });
        }
    });
    // Add the command to the launcher
    if (launcher) {
        launcher.add({
            command: CommandIDs.createNew,
            category: 'Other',
            rank: 1
        });
    }
    // Add the command to the palette
    if (palette) {
        palette.addItem({
            command: CommandIDs.createNew,
            args: { isPalette: true },
            category: PALETTE_CATEGORY
        });
    }
};
const jcadPlugin = {
    id: 'jupytercad:jcadplugin',
    requires: [
        IJupyterCadDocTracker,
        IThemeManager,
        IAnnotationToken,
        IFileBrowserFactory,
        IJCadWorkerRegistryToken,
        IJCadExternalCommandRegistryToken
    ],
    optional: [ILauncher, ICommandPalette, ICollaborativeDrive],
    autoStart: true,
    activate
};
export default jcadPlugin;

==> jupytercad_core-3.0.0a3.tar.gz: jupytercad_core-3.0.0a3/lib/jcadplugin/plugins.js <==
import { ICollaborativeDrive } from '@jupyter/docprovider';
import { logoIcon } from '@jupytercad/base';
import { IAnnotationToken, IJCadExternalCommandRegistryToken, IJCadWorkerRegistryToken, IJupyterCadDocTracker, JupyterCadDoc } from '@jupytercad/schema';
import { ICommandPalette, IThemeManager } from '@jupyterlab/apputils';
import { IEditorServices } from '@jupyterlab/codeeditor';
import { ConsolePanel, IConsoleTracker } from '@jupyterlab/console';
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
import { ILauncher } from '@jupyterlab/launcher';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
import { JupyterCadWidgetFactory } from '../factory';
import { JupyterCadJcadModelFactory } from './modelfactory';
const FACTORY = 'JupyterCAD .jcad Viewer';
const PALETTE_CATEGORY = 'JupyterCAD';
var CommandIDs;
(function (CommandIDs) {
    CommandIDs.createNew = 'jupytercad:create-new-jcad-file';
})(CommandIDs || (CommandIDs = {}));
const activate = (app, tracker, themeManager, annotationModel, browserFactory, workerRegistry, externalCommandRegistry, contentFactory, editorServices, rendermime, consoleTracker, launcher, palette, drive) => {
    const widgetFactory = new JupyterCadWidgetFactory({
        name: FACTORY,
        modelName: 'jupytercad-jcadmodel',
        fileTypes: ['jcad'],
        defaultFor: ['jcad'],
        tracker,
        commands: app.commands,
        workerRegistry,
        externalCommandRegistry,
        manager: app.serviceManager,
        contentFactory,
        rendermime,
        mimeTypeService: editorServices.mimeTypeService,
        consoleTracker
    });
    // Registering the widget factory
    app.docRegistry.addWidgetFactory(widgetFactory);
    // Creating and registering the model factory for our custom DocumentModel
    const modelFactory = new JupyterCadJcadModelFactory({
        annotationModel
    });
    app.docRegistry.addModelFactory(modelFactory);
    // register the filetype
    app.docRegistry.addFileType({
        name: 'jcad',
        displayName: 'JCAD',
        mimeTypes: ['text/json'],
        extensions: ['.jcad', '.JCAD'],
        fileFormat: 'text',
        contentType: 'jcad',
        icon: logoIcon
    });
    const jcadSharedModelFactory = () => {
        return new JupyterCadDoc();
    };
    if (drive) {
        drive.sharedModelFactory.registerDocumentFactory('jcad', jcadSharedModelFactory);
    }
    widgetFactory.widgetCreated.connect((sender, widget) => {
        widget.context.pathChanged.connect(() => {
            tracker.save(widget);
        });
        themeManager.themeChanged.connect((_, changes) => widget.context.model.themeChanged.emit(changes));
        tracker.add(widget);
        app.shell.activateById('jupytercad::leftControlPanel');
        app.shell.activateById('jupytercad::rightControlPanel');
    });
    app.commands.addCommand(CommandIDs.createNew, {
        label: args => 'CAD File',
        caption: 'Create a new JCAD Editor',
        icon: logoIcon,
        execute: async (args) => {
            var _a;
            // Get the directory in which the JCAD file must be created;
            // otherwise take the current filebrowser directory
            const cwd = (args['cwd'] ||
                ((_a = browserFactory.tracker.currentWidget) === null || _a === void 0 ? void 0 : _a.model.path));
            // Create a new untitled Blockly file
            let model = await app.serviceManager.contents.newUntitled({
                path: cwd,
                type: 'file',
                ext: '.jcad'
            });
            model = await app.serviceManager.contents.save(model.path, Object.assign(Object.assign({}, model), { format: 'text', size: undefined, content: '{\n\t"objects": [],\n\t"options": {},\n\t"metadata": {},\n\t"outputs": {}}' }));
            // Open the newly created file with the 'Editor'
            return app.commands.execute('docmanager:open', {
                path: model.path,
                factory: FACTORY
            });
        }
    });
    // Add the command to the launcher
    if (launcher) {
        launcher.add({
            command: CommandIDs.createNew,
            category: 'Other',
            rank: 1
        });
    }
    // Add the command to the palette
    if (palette) {
        palette.addItem({
            command: CommandIDs.createNew,
            category: PALETTE_CATEGORY
        });
    }
};
const jcadPlugin = {
    id: 'jupytercad:jcadplugin',
    requires: [
        IJupyterCadDocTracker,
        IThemeManager,
        IAnnotationToken,
        IFileBrowserFactory,
        IJCadWorkerRegistryToken,
        IJCadExternalCommandRegistryToken,
        ConsolePanel.IContentFactory,
        IEditorServices,
        IRenderMimeRegistry,
        IConsoleTracker
    ],
    optional: [ILauncher, ICommandPalette, ICollaborativeDrive],
    autoStart: true,
    activate
};
export default jcadPlugin;
